@@ -1,6 +1,6 @@
 package Test::SVN::Repo;
 # ABSTRACT: Subversion repository fixtures for testing
-$Test::SVN::Repo::VERSION = '0.016'; # TRIAL
+$Test::SVN::Repo::VERSION = '0.021'; # TRIAL
 use strict;
 use warnings;
 
@@ -10,10 +10,9 @@ use File::Temp      qw( tempdir );
 use Path::Class     ();
 use POSIX           qw( :errno_h strerror );
 use Scalar::Util    qw( weaken );
-use Try::Tiny       qw( catch try );
 use URI::file       ();
 
-use base qw( Class::Accessor Test::Builder::Module );
+use base qw( Class::Accessor );
 
 __PACKAGE__->mk_ro_accessors(qw(
         root_path users keep_files verbose start_port end_port retry_count
@@ -31,7 +30,11 @@ sub CLEANUP {
     }
     exit(0);
 }
-$SIG{$_} = \&CLEANUP for qw( HUP INT QUIT TERM );
+
+for my $sig (qw( ABRT BUS EMT FPE HUP ILL INT PIPE QUIT SEGV SYS TERM TRAP )) {
+    next unless exists $SIG{$sig};
+    $SIG{$sig} = \&CLEANUP
+}
 END { CLEANUP() }
 
 #------------------------------------------------------------------------------
@@ -168,7 +171,7 @@ sub _choose_random_port {
 sub _try_spawn_server {
     my ($self, $port) = @_;
     # We're checking message text - need to ensure known locale
-    local $ENV{LC_MESSAGES} = 'C';
+    local $ENV{LC_ALL} = 'C';
     my @cmd = ( 'svnserve',
                 '-d',           # daemon mode
                 '--foreground', # don't actually daemonize
@@ -195,7 +198,7 @@ sub _try_spawn_server {
     # Final fallback for stubborn locales
     my $eaddrinuse_msg = strerror($eaddrinuse);
     return 0 if ($err =~ /\Q$eaddrinuse_msg\E/i);
-    die $err;
+    die "$err (EADDRINUSE=\"$eaddrinuse_msg\")\n";
 }
 
 sub _get_server_pid {
@@ -260,7 +263,7 @@ Test::SVN::Repo - Subversion repository fixtures for testing
 
 =head1 VERSION
 
-version 0.016
+version 0.021
 
 =head1 SYNOPSIS
 
